@@ -614,6 +614,13 @@ mod tests {
             "-123456789.987654321",
             "8.000000009900000000990000000099",
         );
+        assert_div("1", "3", "0.33333333333333333333333333333333333333");
+        assert_div("1", "33", "0.030303030303030303030303030303030303030");
+        assert_div(
+            "-3.1415926",
+            "-0.12345678901234567890123456789012345678",
+            "25.446900289022102624101133879320318304",
+        );
     }
 
     #[test]
